spacepy.data_assimilation.output — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- data assimilation - data assimilation module »

# spacepy.data_assimilation.output

`spacepy.data_assimilation.` `output`(init, result)

  write results to file and be done

  Parameters: | model : : PSDdata : : HAp : :
  Returns: | out : :

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- data assimilation - data assimilation module »